# Changelog

## 2.1.1 - 2025-08-11
- Add py.typed to all top level packages

## 2.1.0 - 2025-07-09
- Initial public release targeting integration with the
  [Planet Client for Python](https://github.com/planetlabs/planet-client-python).

## 2.0.11 - 2025-07-09
- Final 2.0 series development release.

## [Unreleased: 2.0.*]
- All releases in the 2.0.X series are development releases, even if not
  tagged as such. This work included some shakedowns of the release pipelines.
